==> seedsui-react-2.6.2.tgz: package/es/Preview/Preview.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';
import Instance from './instance.js';

var Preview = (_temp = _class = function (_Component) {
  _inherits(Preview, _Component);

  function Preview(props) {
    _classCallCheck(this, Preview);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Preview.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    if (!this.instance) return false;
    if (this.props.src !== prevProps.src || this.props.layerHTML !== prevProps.layerHTML) {
      this.instance.setSrc(this.props.src);
      this.instance.setLayerHTML(this.props.layerHTML);
      this.instance.update();
    }
    if (this.props.show !== prevProps.show) {
      if (this.props.show) this.instance.show();else this.instance.hide();
    }
  };

  Preview.prototype.componentDidMount = function componentDidMount() {
    if (this.instance) return;
    var instance = new Instance({
      mask: this.$el,
      showHeader: this.props.showHeader,
      src: this.props.src,
      layerHTML: this.props.layerHTML,
      onClickBack: this.props.onClickBack,
      onClick: this.props.onClickBack
    });
    this.instance = instance;
  };

  Preview.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        src = _props.src,
        layerHTML = _props.layerHTML,
        onClickBack = _props.onClickBack,
        others = _objectWithoutProperties(_props, ['portal', 'show', 'src', 'layerHTML', 'onClickBack']);

    if (!src) {
      return null;
    }
    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: 'preview-mask' }, others),
      React.createElement(
        'div',
        { className: 'preview-header' },
        React.createElement('div', { className: 'preview-header-back' })
      ),
      React.createElement('div', { className: 'preview-container' })
    ), portal || document.getElementById('root'));
  };

  return Preview;
}(Component), _class.defaultProps = {
  show: false,
  showHeader: false
}, _temp);
export { Preview as default };
Preview.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  show: PropTypes.bool,
  showHeader: PropTypes.bool,

  src: PropTypes.string,
  layerHTML: PropTypes.string,

  onClickBack: PropTypes.func
} : {};

==> seedsui-react-3.6.8.tgz: package/es/Preview/Preview.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';
import Instance from './instance.js';

var Preview = (_temp = _class = function (_Component) {
  _inherits(Preview, _Component);

  function Preview(props) {
    _classCallCheck(this, Preview);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Preview.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    if (!this.instance) return false;
    if (this.props.src !== prevProps.src || this.props.layerHTML !== prevProps.layerHTML) {
      this.instance.setSrc(this.props.src);
      this.instance.setLayerHTML(this.props.layerHTML);
      this.instance.update();
    }
    if (this.props.show !== prevProps.show) {
      if (this.props.show) this.instance.show();else this.instance.hide();
    }
  };

  Preview.prototype.componentDidMount = function componentDidMount() {
    if (this.instance) return;
    var instance = new Instance({
      mask: this.$el,
      showHeader: this.props.showHeader,
      src: this.props.src,
      layerHTML: this.props.layerHTML,
      onClickBack: this.props.onClickBack,
      onClick: this.props.onClickBack
    });
    this.instance = instance;
  };

  Preview.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        src = _props.src,
        layerHTML = _props.layerHTML,
        onClickBack = _props.onClickBack,
        others = _objectWithoutProperties(_props, ['portal', 'show', 'src', 'layerHTML', 'onClickBack']);

    if (!src) {
      return null;
    }
    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: 'preview-mask' }, others),
      React.createElement(
        'div',
        { className: 'preview-header' },
        React.createElement('div', { className: 'preview-header-back' })
      ),
      React.createElement('div', { className: 'preview-container' })
    ), portal || document.getElementById('root') || document.body);
  };

  return Preview;
}(Component), _class.defaultProps = {
  show: false,
  showHeader: false
}, _temp);
export { Preview as default };
Preview.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  show: PropTypes.bool,
  showHeader: PropTypes.bool,

  src: PropTypes.string,
  layerHTML: PropTypes.string,

  onClickBack: PropTypes.func
} : {};
